powered by
A helper function to map an input of various types to a timestamp string suitable for use with Prometheus.
cast_timestamp(input)
A Prometheus-compatible timestamp that can be coerced to a string.
A RFC3339 timestamp string, numerical unix timestamp, or POSIXct object.